==> go.php?file=PhoenixStyle1.559.zip: PhoenixStyleMod_Firelands/Localization/localization-zhTW.lua <==
﻿if GetLocale() == "zhTW" then


function psfirellocale()

	psfirebabah = "爆炸" -- Needs review
	psfirebabah2 = "|s4id98620,100215,100216,100217|id對玩家造成傷害" -- Needs review
	psfirebaleroccrystal = "水晶" -- Needs review
	psfireby = "由" -- Needs review
	psfireconsumeadd = "燼網雄蛛獲得|sid100634|id" -- Needs review
	psfiredamshared = "爆炸擴及於" -- Needs review
	psfiredeadrag = "死" -- Needs review
	psfirediddamageto = "造成傷害於" -- Needs review
	psfirediedfrom = "死於" -- Needs review
	psfireended = "結束" -- Needs review
	psfirefixate1 = "最後一個在%s秒前結束於" -- Needs review
	psfirehealedhimself = "治療" -- Needs review
	psfireintershanox = "打斷" -- Needs review
	psfirekilledplayer = "殺死玩家!" -- Needs review
	psfirekilledplayers = "殺死%s個玩家!" -- Needs review
	psfireldamagefrom = "受到傷害" -- Needs review
	psfirelgot = "中了" -- Needs review
	psfirelgotinf = "中了" -- Needs review
	psfirelgotinm = "中了" -- Needs review
	psfirelgotm = "中了" -- Needs review
	psfirellastmoduleloadtxt = "火源之界" -- Needs review
	psfireltotal = "總計" -- Needs review
	psfirelwhogot = "誰中了" -- Needs review
	psfiremajodamag1 = "所有人受到傷害!" -- Needs review
	psfiremajodamag2 = "未分攤|s4id98474,100212,100213,100214|id的傷害" -- Needs review
	psfiremajodamag3 = "未受到傷害" -- Needs review
	psfiremajogotdmg1 = "|s4id98474,100212,100213,100214|id傷害" -- Needs review
	psfiremajogotdmg2 = "只有一個人受到傷害" -- Needs review
	psfiremajogotdmg3 = "傷害" -- Needs review
	psfiremaybeexcessd = "可能有額外的傷害" -- Needs review
	psfireno = "無" -- Needs review
	psfirenofistsec2 = "不計前2秒" -- Needs review
	psfirenotsure = "不確定" -- Needs review
	psfireragnaknock1 = "玩家受到|sid100115|id的額外傷害。插件未發現其他人在6碼內。" -- Needs review
	psfireragnaknock2 = "中了%s除了" -- Needs review
	psfireragnaknock3 = "在6碼內" -- Needs review
	psfireshanaddopt1 = "長矛的範圍傷害" -- Needs review
	psfireshanaddopt2 = "長矛的傷害" -- Needs review
	psfireshanaddopt3 = "額外的" -- Needs review
	psfirestaks = "次" -- Needs review
	psfiretauntseff = "對燼網紡織者使用嘲諷(有效的)" -- Needs review
	psfiretauntseff2 = "對燼網紡織者使用嘲諷" -- Needs review
	psfiretimes = "次" -- Needs review
	psfiretrapragna1 = "太近的玩家(最多8碼):" -- Needs review
	psfiretrapragna2 = "未發現任何人在8碼內" -- Needs review
	psfiretxtopt512 = "|tip2 首領由|sid99332|id獲得多少治療" -- Needs review
	psfiretxtopt515 = "|tip1 如果有額外的人受到|sid100833|id的傷害-提示誰坦燼網雄蛛等(|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt516 = "|tip1 如果有超過1人受到|sid100838|id的傷害-提示訊息(|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt517 = "誰對燼網紡織者使用嘲諷技能(更多訊息在'戰鬥中訊息'模組)" -- Needs review
	psfiretxtopt518 = "|tip2 燼網雄蛛獲得幾次|sid100634|id" -- Needs review
	psfiretxtopt522 = "|tip2 液態黑曜石施放幾次|sid99875|id" -- Needs review
	psfiretxtopt533 = "|tip1 提示如果不是玩家獲得|sid100359|id" -- Needs review
	psfiretxtopt544 = "|tip2 誰攻擊怒面並中斷了牠的|sid99947|id(總計)" -- Needs review
	psfiretxtopt551 = "|tip1 如果玩家在|sid99403|id時被暗影水晶殺死-顯示訊息(誰刷新它-|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt552 = "|tip1 如果玩家在|sid99403|id時被|sid99353|id殺死-顯示訊息(誰刷新它-|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt553 = "|tip1 提示誰有|sid99516|id如果它造成滅團(|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt561 = "誰的|sid98620|id造成傷害" -- Needs review
	psfiretxtopt562 = "誰的|sid98620|id造成傷害(總計)" -- Needs review
	psfiretxtopt563 = "|tip1 誰沒有分攤|sid100214|id的傷害(忽略|sid100215|id剩餘或剛消散7秒內的玩家)" -- Needs review
	psfiretxtopt564 = "|tip1 誰沒有分攤|sid100214|id的傷害(忽略|sid100215|id剩餘或剛消散7秒內的玩家)-總計" -- Needs review
	psfiretxtopt565 = "|tip2 獲得|sid98245|id的總時間" -- Needs review
	psfiretxtopt571 = "|tip1 誰觸發|sid98164|id並造成有人因此死亡(|cffff0000距離檢查，不完全準確|r)" -- Needs review
	psfiretxtopt5712 = "|tip1 提示誰受到|sid100115|id波及的傷害" -- Needs review
	psfiretxtopt5713 = "|tip2 提示誰受到|sid100115|id波及的傷害(總計)" -- Needs review
	psfiretxtopt572 = "|tip1 如果對燃體隕石造成總計超過25萬點傷害(也許有額外傷害)" -- Needs review
	psfiretxtopt573 = "|tip1 在|sid100259|id被施放後顯示誰傷害或擊暈烈焰之子" -- Needs review
	psfiretxtopt574 = "|tip2 |sid101233|id - 誰在陷阱形成時沒有跑開並且受到傷害" -- Needs review
	psfiretxtoptt533 = "|s4id100359|id未對玩家使用! 施放在" -- Needs review
	psfiretxtoptt544 = "打斷|s4id99947|id" -- Needs review
	psfiretxtopttmaj = "|s4id98245|id的總時間(秒)" -- Needs review
	psfirewhodied = "死亡訊息" -- Needs review
	psfirewith = "帶有" -- Needs review
	psfireyard = "碼" -- Needs review



end

end

==> go.php?file=PhoenixStyle1.608.zip: PhoenixStyleMod_Firelands/Localization/localization-zhTW.lua <==
﻿if GetLocale() == "zhTW" then


function psfirellocale()

	psfirebabah = "爆炸" -- Needs review
	psfirebabah2 = "|s4id98620,100215,100216,100217|id對玩家造成傷害" -- Needs review
	psfirebaleroccrystal = "水晶" -- Needs review
	psfireby = "由" -- Needs review
	psfireconsumeadd = "燼網雄蛛獲得|sid100634|id" -- Needs review
	psfiredamshared = "爆炸擴及於" -- Needs review
	psfiredeadrag = "死" -- Needs review
	psfirediddamageto = "造成傷害於" -- Needs review
	psfirediedfrom = "死於" -- Needs review
	psfireended = "結束" -- Needs review
	psfirefixate1 = "最後一個在%s秒前結束於" -- Needs review
	psfirehealedhimself = "治療" -- Needs review
	psfireintershanox = "打斷" -- Needs review
	psfirekilledplayer = "殺死玩家!" -- Needs review
	psfirekilledplayers = "殺死%s個玩家!" -- Needs review
	psfireldamagefrom = "受到傷害" -- Needs review
	psfirelgot = "中了" -- Needs review
	psfirelgotinf = "中了" -- Needs review
	psfirelgotinm = "中了" -- Needs review
	psfirelgotm = "中了" -- Needs review
	psfirellastmoduleloadtxt = "火源之界" -- Needs review
	psfireltotal = "總計" -- Needs review
	psfirelwhogot = "誰中了" -- Needs review
	psfiremajodamag1 = "所有人受到傷害!" -- Needs review
	psfiremajodamag2 = "未分攤|s4id98474,100212,100213,100214|id的傷害" -- Needs review
	psfiremajodamag3 = "未受到傷害" -- Needs review
	psfiremajogotdmg1 = "|s4id98474,100212,100213,100214|id傷害" -- Needs review
	psfiremajogotdmg2 = "只有一個人受到傷害" -- Needs review
	psfiremajogotdmg3 = "傷害" -- Needs review
	psfiremaybeexcessd = "可能有額外的傷害" -- Needs review
	psfireno = "無" -- Needs review
	psfirenofistsec2 = "不計前2秒" -- Needs review
	psfirenotsure = "不確定" -- Needs review
	psfireragnaknock1 = "玩家受到 的額外傷害。插件未發現其他人在6碼內。"
	psfireragnaknock2 = "中了%s除了" -- Needs review
	psfireragnaknock3 = "在6碼內" -- Needs review
	psfireshanaddopt1 = "長矛的範圍傷害" -- Needs review
	psfireshanaddopt2 = "長矛的傷害" -- Needs review
	psfireshanaddopt3 = "額外的" -- Needs review
	psfirestaks = "次" -- Needs review
	psfiretauntseff = "對燼網紡織者使用嘲諷(有效的)" -- Needs review
	psfiretauntseff2 = "對燼網紡織者使用嘲諷" -- Needs review
	psfiretimes = "次" -- Needs review
	psfiretrapragna1 = "太近的玩家(最多8碼):" -- Needs review
	psfiretrapragna2 = "未發現任何人在8碼內" -- Needs review
	psfiretxtopt512 = "|tip2 首領由|sid99332|id獲得多少治療" -- Needs review
	psfiretxtopt515 = "|tip1 如果有額外的人受到|sid99463|id的傷害-提示誰坦燼網雄蛛等(|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt516 = "|tip1 如果有超過1人受到|sid99990|id的傷害-提示訊息(|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt517 = "誰對燼網紡織者使用嘲諷技能(更多訊息在'戰鬥中訊息'模組)" -- Needs review
	psfiretxtopt518 = "|tip2 燼網雄蛛獲得幾次|sid100634|id" -- Needs review
	psfiretxtopt522 = "|tip2 液態黑曜石施放幾次|sid99875|id" -- Needs review
	psfiretxtopt533 = "|tip1 提示如果不是玩家獲得|sid100359|id" -- Needs review
	psfiretxtopt544 = "|tip2 誰攻擊怒面並中斷了牠的|sid99947|id(總計)" -- Needs review
	psfiretxtopt551 = "|tip1 如果玩家在|sid99257|id時被暗影水晶殺死-顯示訊息(誰刷新它-|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt552 = "|tip1 如果玩家在|sid99257|id時被|sid99353|id殺死-顯示訊息(誰刷新它-|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt553 = "|tip1 提示誰有|sid99516|id如果它造成滅團(|cffff0000英雄模式|r)" -- Needs review
	psfiretxtopt561 = "誰的|sid98620|id造成傷害" -- Needs review
	psfiretxtopt562 = "誰的|sid98620|id造成傷害(總計)" -- Needs review
	psfiretxtopt563 = "|tip1 誰沒有分攤|sid98474|id的傷害(忽略|sid98620|id剩餘或剛消散7秒內的玩家)" -- Needs review
	psfiretxtopt564 = "|tip1 誰沒有分攤|sid98474|id的傷害(忽略|sid98620|id剩餘或剛消散7秒內的玩家)-總計" -- Needs review
	psfiretxtopt565 = "|tip2 獲得|sid98245|id的總時間" -- Needs review
	psfiretxtopt571 = "|tip1 誰觸發|sid98164|id並造成有人因此死亡(|cffff0000距離檢查，不完全準確|r)" -- Needs review
	psfiretxtopt5712 = "|tip1 提示誰受到|sid98263|id波及的傷害" -- Needs review
	psfiretxtopt5713 = "|tip2 提示誰受到|sid98263|id波及的傷害(總計)" -- Needs review
	psfiretxtopt572 = "|tip1 如果對燃體隕石造成總計超過25萬點傷害(也許有額外傷害)" -- Needs review
	psfiretxtopt573 = "|tip1 在|sid100259|id被施放後顯示誰傷害或擊暈烈焰之子" -- Needs review
	psfiretxtopt574 = "|tip2 |sid98170|id - 誰在陷阱形成時沒有跑開並且受到傷害" -- Needs review
	psfiretxtoptt533 = "|s4id100359|id未對玩家使用! 施放在" -- Needs review
	psfiretxtoptt544 = "打斷|s4id99947|id" -- Needs review
	psfiretxtopttmaj = "|s4id98245|id的總時間(秒)" -- Needs review
	psfirewhodied = "死亡訊息" -- Needs review
	psfirewith = "帶有" -- Needs review
	psfireyard = "碼" -- Needs review




end

end
